| Title: | Simulation of Plasma Caffeine Concentrations by Using Population Pharmacokinetic Model |
|---|---|
| Description: | Simulate plasma caffeine concentrations using population pharmacokinetic model described in Lee, Kim, Perera, McLachlan and Bae (2015) <doi:10.1007/s00431-015-2581-x> and the package was published <doi:10.12793/tcp.2017.25.3.141>. |
| Authors: | Sungpil Han [aut, cre] (ORCID: <https://orcid.org/0000-0002-4674-7682>) |
| Maintainer: | Sungpil Han <[email protected]> |
| License: | GPL-3 | file LICENSE |
| Version: | 0.2.4.9000 |
| Built: | 2026-06-08 10:40:03 UTC |
| Source: | https://github.com/asancpt/caffsim |
caffConcTime will create a dataset of the concentration-time curve.
caffConcTime(Weight, Dose, N = 20)caffConcTime(Weight, Dose, N = 20)
Weight |
Body weight (kg) |
Dose |
Dose of single caffeine (mg) |
N |
The number of simulated subjects |
The dataset of concentration and time of simulated subjects
https://asancpt.github.io/caffsim
caffConcTime(Weight = 20, Dose = 200, N = 20) caffConcTime(20, 200)caffConcTime(Weight = 20, Dose = 200, N = 20) caffConcTime(20, 200)
caffConcTimeMulti will create a dataset of the concentration-time curve of multiple oral administration of caffeine.
caffConcTimeMulti(Weight, Dose, N = 20, Tau = 8, Repeat = 4)caffConcTimeMulti(Weight, Dose, N = 20, Tau = 8, Repeat = 4)
Weight |
Body weight (kg) |
Dose |
Dose of single caffeine (mg) |
N |
The number of simulated subjects |
Tau |
The interval of multiple dosing (hour) |
Repeat |
The number of dosing |
The dataset of concentration and time of simulated subjects of multiple dosing
https://asancpt.github.io/caffsim
caffConcTimeMulti(Weight = 20, Dose = 200, N = 20, Tau = 8, Repeat = 4) caffConcTimeMulti(20, 200)caffConcTimeMulti(Weight = 20, Dose = 200, N = 20, Tau = 8, Repeat = 4) caffConcTimeMulti(20, 200)
caffDescstat will calculate descriptive statistics of simulated PK parameters
caffDescstat(caffPkparamData)caffDescstat(caffPkparamData)
caffPkparamData |
data frame generated by caffPkparam function |
The descriptive statistics of pharmacokinetic parameters
https://asancpt.github.io/caffsim
caffDescstat(caffPkparam(20,500)) caffDescstat(caffPkparamMulti(20,500)) caffDescExample <- cbind(caffDescstat(caffPkparam(20,500)), caffDescstat(caffPkparam(50,500))[,2]) colnames(caffDescExample)[2:3] <- c('20 kg', '50 kg') caffDescExamplecaffDescstat(caffPkparam(20,500)) caffDescstat(caffPkparamMulti(20,500)) caffDescExample <- cbind(caffDescstat(caffPkparam(20,500)), caffDescstat(caffPkparam(50,500))[,2]) colnames(caffDescExample)[2:3] <- c('20 kg', '50 kg') caffDescExample
caffOverdose calculates a time duration of plasma caffeine concentration over specified toxic limits (40 mg/L or 80 mg/L)
caffOverdose(caffConcTimeData)caffOverdose(caffConcTimeData)
caffConcTimeData |
data frame containing concentration-time data |
descriptive statistics of duration of toxic concentrations
https://asan.shinyapps.io/caff/
caffOverdose(caffConcTime(Weight = 20, Dose = 200, N = 20)) caffOverdose(caffConcTimeMulti(Weight = 20, Dose = 200, N = 20, Tau = 8, Repeat = 4))caffOverdose(caffConcTime(Weight = 20, Dose = 200, N = 20)) caffOverdose(caffConcTimeMulti(Weight = 20, Dose = 200, N = 20, Tau = 8, Repeat = 4))
caffPkparam will create a dataset for simulation of single dose of caffeine
caffPkparam(Weight, Dose, N = 20)caffPkparam(Weight, Dose, N = 20)
Weight |
Body weight (kg) |
Dose |
Dose of single caffeine (mg) |
N |
The number of simulated subjects |
The dataset of pharmacokinetic parameters of subjects after single caffeine dose following multivariate normal
https://asancpt.github.io/caffsim
caffPkparam(Weight = 20, Dose = 200, N = 20) caffPkparam(20,500)caffPkparam(Weight = 20, Dose = 200, N = 20) caffPkparam(20,500)
caffPkparamMulti will create a dataset for simulation of multiple dose of caffeine.
caffPkparamMulti(Weight, Dose, N = 20, Tau = 8)caffPkparamMulti(Weight, Dose, N = 20, Tau = 8)
Weight |
Body weight (kg) |
Dose |
Dose of multiple caffeine (mg) |
N |
The number of simulated subjects |
Tau |
The interval of multiple dosing (hour) |
The dataset of pharmacokinetic parameters of subjects after multiple caffeine dose following multivariate normal
https://asancpt.github.io/caffsim
caffPkparamMulti(Weight = 20, Dose = 200, N = 20, Tau = 8) caffPkparamMulti(20,500)caffPkparamMulti(Weight = 20, Dose = 200, N = 20, Tau = 8) caffPkparamMulti(20,500)
caffPlot will create concentration-time curve after single dose of caffeine
caffPlot(caffConcTimeData, log = FALSE)caffPlot(caffConcTimeData, log = FALSE)
caffConcTimeData |
data frame of concentration-time dataset having column names Subject, Time, and Conc (case-sensitive) |
log |
y axis log |
The concentration-time curve
https://asancpt.github.io/caffsim
caffPlot(caffConcTime(Weight = 20, Dose = 200, N = 20))caffPlot(caffConcTime(Weight = 20, Dose = 200, N = 20))
caffPlotMulti will create concentration-time curve after multiple doses of caffeine
caffPlotMulti(caffConcTimeMultiData, log = FALSE)caffPlotMulti(caffConcTimeMultiData, log = FALSE)
caffConcTimeMultiData |
data frame of concentration-time dataset having column names Subject, Time, and Conc (case-sensitive) |
log |
y axis log |
The concentration-time curve
https://asancpt.github.io/caffsim
caffPlotMulti(caffConcTimeMulti(Weight = 20, Dose = 200, N = 20, Tau = 8, Repeat = 4))caffPlotMulti(caffConcTimeMulti(Weight = 20, Dose = 200, N = 20, Tau = 8, Repeat = 4))
caffShiny runs an internal shiny app Caffeine Concentration Predictor in order to interactively simulate plasma caffeine concentration.
caffShiny()caffShiny()
https://asan.shinyapps.io/caff/
A dataset containing information regarding unit data of pharmacokinetic parameters
UnitTableUnitTable
A data frame with 16 rows and 2 variables:
Abbreviated pharmacokinetic parameters
Pharmacokinetic parameters in full name
https://asancpt.github.io/caffsim